@@ -1180,7 +1180,8 @@ class PDO  {
  * associated result set.
  * @link https://php.net/manual/en/class.pdostatement.php
  */
-class PDOStatement implements Traversable {
+class PDOStatement implements IteratorAggregate
+{
 	/**
 	 * @var string
 	 */
@@ -1252,7 +1253,7 @@ class PDOStatement implements Traversable {
 	 * question mark placeholders, this will be the 1-indexed position of
 	 * the parameter.
 	 * </p>
-	 * @param mixed $variable <p>
+	 * @param mixed &$variable <p>
 	 * Name of the PHP variable to bind to the SQL statement parameter.
 	 * </p>
 	 * @param int $data_type [optional] <p>
@@ -1282,7 +1283,7 @@ class PDOStatement implements Traversable {
 	 * If using the column name, be aware that the name should match the
 	 * case of the column, as returned by the driver.
 	 * </p>
-	 * @param mixed $param <p>
+	 * @param mixed &$param <p>
 	 * Name of the PHP variable to which the column will be bound.
 	 * </p>
 	 * @param int $type [optional] <p>
@@ -1372,14 +1373,7 @@ class PDOStatement implements Traversable {
 	 * column, bitwise-OR <b>PDO::FETCH_COLUMN</b> with
 	 * <b>PDO::FETCH_GROUP</b>.
 	 * </p>
-	 * @param mixed $fetch_argument [optional] <p>
-	 * This argument have a different meaning depending on the value of
-	 * the <i>fetch_style</i> parameter:
-	 * <p>
-	 * <b>PDO::FETCH_COLUMN</b>: Returns the indicated 0-indexed
-	 * column.
-	 * </p>
-	 * @param array $ctor_args [optional] <p>
+	 * @param mixed ...$fetch_args <p>
 	 * Arguments of custom class constructor when the <i>fetch_style</i>
 	 * parameter is <b>PDO::FETCH_CLASS</b>.
 	 * </p>
@@ -1396,7 +1390,7 @@ class PDOStatement implements Traversable {
 	 * ORDER BY clauses in SQL to restrict results before retrieving and
 	 * processing them with PHP.
 	 */
-	public function fetchAll ($fetch_style = null, $fetch_argument = null, array $ctor_args = array()) {}
+	public function fetchAll ($fetch_style = PDO::FETCH_BOTH, ...$fetch_args) {}
 
 	/**
 	 * (PHP 5 &gt;= 5.1.0, PHP 7, PECL pdo &gt;= 0.2.4)<br/>
@@ -1554,7 +1548,7 @@ class PDOStatement implements Traversable {
 	 * @param array $ctorarfg [optional] <p> Constructor arguments. </p>
 	 * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
 	 */
-	public function setFetchMode ($mode, $classNameObject = null, array $ctorarfg = array()) {}
+	public function setFetchMode ($mode, $className = null, array $params = array()) {}
 
 	/**
 	 * (PHP 5 &gt;= 5.1.0, PHP 7, PECL pdo &gt;= 0.2.0)<br/>
@@ -1584,6 +1578,10 @@ class PDOStatement implements Traversable {
 
 	final public function __sleep () {}
 
+	/**
+	 * @since 8.0
+	 */
+	public function getIterator(){}
 }
 
 final class PDORow  {
