@@ -10,24 +10,24 @@ class SQLiteDatabase  {
 	/**
 	 * (PHP 5 &lt; 5.4.0, PECL sqlite &gt;= 1.0.0)
 	 * @link https://php.net/manual/en/function.sqlite-open.php
-	 * @param $filename <p>The filename of the SQLite database. If the file does not exist, SQLite will attempt to create it. PHP must have write permissions to the file if data is inserted, the database schema is modified or to create the database if it does not exist.</p>
-	 * @param $mode [optional] <p>The mode of the file. Intended to be used to open the database in read-only mode. Presently, this parameter is ignored by the sqlite library. The default value for mode is the octal value 0666 and this is the recommended value.</p>
-	 * @param $error_message [optional] <p>Passed by reference and is set to hold a descriptive error message explaining why the database could not be opened if there was an error.</p>
+	 * @param string $filename <p>The filename of the SQLite database. If the file does not exist, SQLite will attempt to create it. PHP must have write permissions to the file if data is inserted, the database schema is modified or to create the database if it does not exist.</p>
+	 * @param int $mode [optional] <p>The mode of the file. Intended to be used to open the database in read-only mode. Presently, this parameter is ignored by the sqlite library. The default value for mode is the octal value 0666 and this is the recommended value.</p>
+	 * @param string &$error_message [optional] <p>Passed by reference and is set to hold a descriptive error message explaining why the database could not be opened if there was an error.</p>
 	 */
 	final public function __construct ($filename, $mode = 0666, &$error_message) {}
 
 	/**
 	 * (PHP 5 &lt; 5.4.0, PECL sqlite &gt;= 1.0.0)
 	 * @link https://php.net/manual/en/function.sqlite-query.php
-	 * @param $query <p>
+	 * @param string $query <p>
 	 * The query to be executed.
 	 * </p>
 	 * <p>
 	 * Data inside the query should be {@link https://php.net/manual/en/function.sqlite-escape-string.php properly escaped}.
 	 * </p>
-	 * @param $result_type [optional]
+	 * @param int $result_type [optional]
 	 * <p>The optional <i>result_type</i> parameter accepts a constant and determines how the returned array will be indexed. Using <b>SQLITE_ASSOC</b> will return only associative indices (named fields) while <b>SQLITE_NUM</b> will return only numerical indices (ordinal field numbers). <b>SQLITE_BOTH</b> will return both associative and numerical indices. <b>SQLITE_BOTH</b> is the default for this function.</p>
-	 * @param $error_message [optional] <p>The specified variable will be filled if an error occurs. This is specially important because SQL syntax errors can't be fetched using the {@see sqlite_last_error()} function.</p>
+	 * @param string &$error_message [optional] <p>The specified variable will be filled if an error occurs. This is specially important because SQL syntax errors can't be fetched using the {@see sqlite_last_error()} function.</p>
 	 * @return resource|false <p>
 	 * This function will return a result handle or <b>FALSE</b> on failure.
 	 * For queries that return rows, the result handle can then be used with
@@ -59,7 +59,7 @@ class SQLiteDatabase  {
 	 * <p>
 	 * Data inside the query should be {@link https://php.net/manual/en/function.sqlite-escape-string.php properly escaped}.
 	 * </p>
-	 * @param string $error_message [optional] <p>The specified variable will be filled if an error occurs. This is specially important because SQL syntax errors can't be fetched using the
+	 * @param string &$error_message [optional] <p>The specified variable will be filled if an error occurs. This is specially important because SQL syntax errors can't be fetched using the
 	 * {@see sqlite_last_error()} function.</p>
 	 * @return bool <p>
 	 * This function will return a boolean result; <b>TRUE</b> for success or <b>FALSE</b> for failure.
@@ -122,20 +122,20 @@ class SQLiteDatabase  {
 	 * (PHP 5 &lt; 5.4.0, PECL sqlite &gt;= 1.0.0)
 	 * Execute a query that does not prefetch and buffer all data
 	 * @link https://php.net/manual/en/function.sqlite-unbuffered-query.php
-	 * @param $query  <p>
+	 * @param string $query  <p>
 	 * The query to be executed.
 	 * </p>
 	 * <p>
 	 * Data inside the query should be {@link https://php.net/manual/en/function.sqlite-escape-string.php properly escaped}.
 	 * </p>
-	 * @param $result_type [optional] <p>The optional <i>result_type</i> parameter accepts a constant and determines how the returned array will be indexed.
+	 * @param int $result_type [optional] <p>The optional <i>result_type</i> parameter accepts a constant and determines how the returned array will be indexed.
 	 * Using <b>SQLITE_ASSOC</b> will return only associative indices (named fields) while <b>SQLITE_NUM</b> will return only numerical indices (ordinal field numbers).
 	 * <b>SQLITE_BOTH</b> will return both associative and numerical indices. <b>SQLITE_BOTH</b> is the default for this function.
-	 * @param $error_message [optional]
+	 * @param string &$error_message [optional]
 	 * @return resource Returns a result handle or <b>FALSE</b> on failure.
 	 * {@see sqlite_unbuffered_query()} returns a sequential forward-only result set that can only be used to read each row, one after the other.
 	 */
-	public function unbufferedQuery ($query, $result_type = SQLITE_BOTH, &$error_message) {}
+	public function unbufferedQuery ($query, $result_type = SQLITE_BOTH, &$error_message = null) {}
 
 	/**
 	 * (PHP 5 &lt; 5.4.0, PECL sqlite &gt;= 1.0.0)
@@ -517,7 +517,7 @@ final class SQLiteException extends RuntimeException  {
 	/**
 	 * Clone the exception
 	 * @link https://php.net/manual/en/exception.clone.php
-	 * @return void 
+	 * @return void
 	 * @since 5.1.0
 	 */
 	final private function __clone () {}
@@ -558,7 +558,7 @@ final class SQLiteException extends RuntimeException  {
  * library. The default value for mode is the octal value
  * 0666 and this is the recommended value.
  * </p>
- * @param string $error_message [optional] <p>
+ * @param string &$error_message [optional] <p>
  * Passed by reference and is set to hold a descriptive error message
  * explaining why the database could not be opened if there was an error.
  * </p>
@@ -582,7 +582,7 @@ function sqlite_open ($filename, $mode = null, &$error_message = null) {}
  * library. The default value for mode is the octal value
  * 0666 and this is the recommended value.
  * </p>
- * @param string $error_message [optional] <p>
+ * @param string &$error_message [optional] <p>
  * Passed by reference and is set to hold a descriptive error message
  * explaining why the database could not be opened if there was an error.
  * </p>
@@ -621,7 +621,7 @@ function sqlite_close ($dbhandle) {}
  * only numerical indices (ordinal field numbers). <b>SQLITE_BOTH</b>
  * will return both associative and numerical indices.
  * <b>SQLITE_BOTH</b> is the default for this function.</p>
- * @param mixed $error_msg [optional] <p>
+ * @param string &$error_msg [optional] <p>
  * The specified variable will be filled if an error occurs. This is
  * specially important because SQL syntax errors can't be fetched using
  * the
@@ -646,7 +646,7 @@ function sqlite_close ($dbhandle) {}
  * recommended that you use the much higher performance
  * {@see sqlite_unbuffered_query} instead.
  */
-function sqlite_query ($query, $dbhandle, $result_type = null, &$error_msg = SQLITE_BOTH) {}
+function sqlite_query ($query, $dbhandle, $result_type = SQLITE_BOTH, &$error_msg = null) {}
 
 /**
  * (PHP 5, PECL sqlite &gt;= 1.0.3)<br/>
@@ -663,7 +663,7 @@ function sqlite_query ($query, $dbhandle, $result_type = null, &$error_msg = SQL
  * {@see sqlite_open()} when used procedurally. This parameter
  * is not required when using the object-oriented method.
  * </p>
- * @param string $error_msg [optional] <p>
+ * @param string &$error_msg [optional] <p>
  * The specified variable will be filled if an error occurs. This is
  * specially important because SQL syntax errors can't be fetched using
  * the
@@ -740,9 +740,9 @@ function sqlite_fetch_array ($result, $result_type = SQLITE_BOTH, $decode_binary
  * Fetches the next row from a result set as an object
  * @link https://php.net/manual/en/function.sqlite-fetch-object.php
  * @param resource $result
- * @param string $class_name [optional] 
- * @param array $ctor_params [optional] 
- * @param bool $decode_binary [optional] 
+ * @param string $class_name [optional]
+ * @param array $ctor_params [optional]
+ * @param bool $decode_binary [optional]
  * @return object
  */
 function sqlite_fetch_object ($result, $class_name = null, array $ctor_params = null, $decode_binary = null) {}
@@ -1072,7 +1072,7 @@ function sqlite_error_string ($error_code) {}
  * Data inside the query should be properly escaped.
  * </p>
  * @param int $result_type [optional] &sqlite.result-type;
- * @param string $error_msg [optional] <p>
+ * @param string &$error_msg [optional] <p>
  * The specified variable will be filled if an error occurs. This is
  * specially important because SQL syntax errors can't be fetched using
  * the sqlite_last_error function.
@@ -1145,11 +1145,11 @@ function sqlite_create_function ($dbhandle, $function_name, $callback, $num_args
  * library. The default value for mode is the octal value
  * 0666 and this is the recommended value.
  * </p>
- * @param string $error_message [optional] <p>
+ * @param string &$error_message [optional] <p>
  * Passed by reference and is set to hold a descriptive error message
  * explaining why the database could not be opened if there was an error.
  * </p>
- * @return SQLiteDatabase a SQLiteDatabase object on success, &null; on error.
+ * @return SQLiteDatabase|null a SQLiteDatabase object on success, null on error.
  */
 function sqlite_factory ($filename, $mode = null, &$error_message = null) {}
 
@@ -1171,7 +1171,7 @@ function sqlite_udf_encode_binary ($data) {}
  * @param string $data <p>
  * The encoded data that will be decoded, data that was applied by either
  * sqlite_udf_encode_binary or
- * sqlite_escape_string. 
+ * sqlite_escape_string.
  * </p>
  * @return string The decoded string.
  */
@@ -1397,4 +1397,3 @@ define ('SQLITE_DONE', 101);
  * @link https://php.net/manual/en/sqlite.constants.php
  */
 define('SQLITE3_DETERMINISTIC', 2048);
-
