@@ -148,11 +148,11 @@ function fann_create_shortcut_array($num_layers, $layers)
  * @param int $num_layers
  * @param int $num_neurons1
  * @param int $num_neurons2
- * @param int $_
+ * @param int ...$_
  *
  * @return resource|false Returns a neural network resource on success, or false on error.
  */
-function fann_create_shortcut($num_layers, $num_neurons1, $num_neurons2, $_ = null)
+function fann_create_shortcut($num_layers, $num_neurons1, $num_neurons2, ...$_)
 {
 }
 
@@ -178,11 +178,11 @@ function fann_create_sparse_array($connection_rate, $num_layers, $layers)
  * @param int $num_layers
  * @param int $num_neurons1
  * @param int $num_neurons2
- * @param int $_
+ * @param int ...$_
  *
  * @return resource|false Returns a neural network resource on success, or false on error.
  */
-function fann_create_sparse($connection_rate, $num_layers, $num_neurons1, $num_neurons2, $_ = null)
+function fann_create_sparse($connection_rate, $num_layers, $num_neurons1, $num_neurons2, ...$_)
 {
 }
 
@@ -206,11 +206,11 @@ function fann_create_standard_array($num_layers, $layers)
  * @param int $num_layers
  * @param int $num_neurons1
  * @param int $num_neurons2
- * @param int $_
+ * @param int ...$_
  *
  * @return resource|false Returns a neural network resource on success, or false on error.
  */
-function fann_create_standard($num_layers, $num_neurons1, $num_neurons2, $_ = null)
+function fann_create_standard($num_layers, $num_neurons1, $num_neurons2, ...$_)
 {
 }
 
